Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
SentryDSN string `help:"the DSN used for logging errors to Sentry"`
DB string `help:"URL describing how to connect to the RapidPro database"`
DBPoolSize int `help:"the size of our db pool"`
Redis string `help:"URL describing how to connect to Redis"`
Version string `help:"the version of this mailroom install"`
LogLevel string `help:"the logging level courier should use"`
SMTPServer string `help:"the smtp configuration for sending emails ex: smtp://user%40password@server:port/?from=foo%40gmail.com"`
BatchWorkers int `help:"the number of go routines that will be used to handle batch events"`
HandlerWorkers int `help:"the number of go routines that will be used to handle messages"`
RetryPendingMessages bool `help:"whether to requeue pending messages older than five minutes to retry"`
MaxValueLength int `help:"the maximum size in characters for contact field values and run result values"`
MaxStepsPerSprint int `help:"the maximum number of steps allowed per engine sprint"`
LibratoUsername string `help:"the username that will be used to authenticate to Librato"`
LibratoToken string `help:"the token that will be used to authenticate to Librato"`
Domain string `help:"the domain that mailroom is listening on"`
AttachmentDomain string `help:"the domain that will be used for relative attachment"`
S3Endpoint string `help:"the S3 endpoint we will write attachments to"`
S3Region string `help:"the S3 region we will write attachments to"`
S3MediaBucket string `help:"the S3 bucket we will write attachments to"`
S3MediaPrefix string `help:"the prefix that will be added to attachment filenames"`
S3DisableSSL bool `` /* 158-byte string literal not displayed */
S3ForcePathStyle bool `` /* 127-byte string literal not displayed */
AWSAccessKeyID string `help:"the access key id to use when authenticating S3"`
AWSSecretAccessKey string `help:"the secret access key id to use when authenticating S3"`
FCMKey string `help:"the FCM API key used to notify Android relayers to sync"`
AuthToken string `help:"the token clients will need to authenticate web requests"`
Address string `help:"the address to bind our web server to"`
Port int `help:"the port to bind our web server to"`
}
Config is our top level configuration object
var Mailroom *Config
func NewMailroomConfig ¶
func NewMailroomConfig() *Config
NewMailroomConfig returns a new default configuration object
Click to show internal directories.
Click to hide internal directories.